@@ -19,7 +19,9 @@ from nova.objects import base
 from nova.objects import fields
 
 
-class VirtualInterface(base.NovaPersistentObject, base.NovaObject):
+# TODO(berrange): Remove NovaObjectDictCompat
+class VirtualInterface(base.NovaPersistentObject, base.NovaObject,
+                       base.NovaObjectDictCompat):
     # Version 1.0: Initial version
     VERSION = '1.0'
 
@@ -65,13 +67,13 @@ class VirtualInterface(base.NovaPersistentObject, base.NovaObject):
             return cls._from_db_object(context, cls(), db_vif)
 
     @base.remotable
-    def create(self, context):
+    def create(self):
         if self.obj_attr_is_set('id'):
             raise exception.ObjectActionError(action='create',
                                               reason='already created')
         updates = self.obj_get_changes()
-        db_vif = db.virtual_interface_create(context, updates)
-        self._from_db_object(context, self, db_vif)
+        db_vif = db.virtual_interface_create(self._context, updates)
+        self._from_db_object(self._context, self, db_vif)
 
     @base.remotable_classmethod
     def delete_by_instance_uuid(cls, context, instance_uuid):
