@@ -19,13 +19,11 @@ import copy
 import datetime
 
 import mock
+from oslo_config import cfg
 from oslo_utils import timeutils
-from six.moves import range
 
 from nova.cells import messaging
 from nova.cells import utils as cells_utils
-from nova.compute import rpcapi as compute_rpcapi
-import nova.conf
 from nova import context
 from nova import objects
 from nova import test
@@ -34,7 +32,9 @@ from nova.tests.unit import fake_instance
 from nova.tests.unit import fake_server_actions
 from nova.tests.unit.objects import test_flavor
 
-CONF = nova.conf.CONF
+CONF = cfg.CONF
+CONF.import_opt('compute_topic', 'nova.compute.rpcapi')
+
 
 FAKE_COMPUTE_NODES = [dict(id=1, host='host1'), dict(id=2, host='host2')]
 FAKE_SERVICES = [dict(id=1, host='host1'),
@@ -222,46 +222,46 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
         instances = ['instance1', 'instance2', 'instance3']
 
         def get_instances_to_sync(context, **kwargs):
-            self.assertEqual(fake_context, context)
+            self.assertEqual(context, fake_context)
             call_info['shuffle'] = kwargs.get('shuffle')
             call_info['project_id'] = kwargs.get('project_id')
             call_info['updated_since'] = kwargs.get('updated_since')
             call_info['get_instances'] += 1
             return iter(instances)
 
-        @staticmethod
         def instance_get_by_uuid(context, uuid):
             return instances[int(uuid[-1]) - 1]
 
         def sync_instance(context, instance):
-            self.assertEqual(fake_context, context)
+            self.assertEqual(context, fake_context)
             call_info['sync_instances'].append(instance)
 
         self.stubs.Set(cells_utils, 'get_instances_to_sync',
                 get_instances_to_sync)
-        self.stubs.Set(objects.Instance, 'get_by_uuid',
+        self.stubs.Set(self.cells_manager.db, 'instance_get_by_uuid',
                 instance_get_by_uuid)
         self.stubs.Set(self.cells_manager, '_sync_instance',
                 sync_instance)
         self.stubs.Set(timeutils, 'utcnow', utcnow)
 
         self.cells_manager._heal_instances(fake_context)
-        self.assertTrue(call_info['shuffle'])
+        self.assertEqual(call_info['shuffle'], True)
         self.assertIsNone(call_info['project_id'])
-        self.assertEqual(updated_since, call_info['updated_since'])
-        self.assertEqual(1, call_info['get_instances'])
+        self.assertEqual(call_info['updated_since'], updated_since)
+        self.assertEqual(call_info['get_instances'], 1)
         # Only first 2
-        self.assertEqual(instances[:2], call_info['sync_instances'])
+        self.assertEqual(call_info['sync_instances'],
+                instances[:2])
 
         call_info['sync_instances'] = []
         self.cells_manager._heal_instances(fake_context)
-        self.assertTrue(call_info['shuffle'])
+        self.assertEqual(call_info['shuffle'], True)
         self.assertIsNone(call_info['project_id'])
-        self.assertEqual(updated_since, call_info['updated_since'])
-        self.assertEqual(2, call_info['get_instances'])
+        self.assertEqual(call_info['updated_since'], updated_since)
+        self.assertEqual(call_info['get_instances'], 2)
         # Now the last 1 and the first 1
-        self.assertEqual([instances[-1], instances[0]],
-                         call_info['sync_instances'])
+        self.assertEqual(call_info['sync_instances'],
+                [instances[-1], instances[0]])
 
     def test_sync_instances(self):
         self.mox.StubOutWithMock(self.msg_runner,
@@ -279,7 +279,7 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
         expected_response = []
         # 3 cells... so 3 responses.  Each response is a list of services.
         # Manager should turn these into a single list of responses.
-        for i in range(3):
+        for i in xrange(3):
             cell_name = 'path!to!cell%i' % i
             services = []
             for service in FAKE_SERVICES:
@@ -389,7 +389,7 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
                                  'proxy_rpc_to_manager')
         fake_response = self._get_fake_response()
         cell_and_host = cells_utils.cell_with_item('fake-cell', 'fake-host')
-        topic = "%s.%s" % (compute_rpcapi.RPC_TOPIC, cell_and_host)
+        topic = "%s.%s" % (CONF.compute_topic, cell_and_host)
         self.msg_runner.proxy_rpc_to_manager(self.ctxt, 'fake-cell',
                 'fake-host', topic, 'fake-rpc-msg',
                 True, -1).AndReturn(fake_response)
@@ -405,7 +405,7 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
         # 3 cells... so 3 responses.  Each response is a list of task log
         # entries. Manager should turn these into a single list of
         # task log entries.
-        for i in range(num):
+        for i in xrange(num):
             cell_name = 'path!to!cell%i' % i
             task_logs = []
             for task_log in FAKE_TASK_LOGS:
@@ -468,7 +468,7 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
         expected_response = []
         # 3 cells... so 3 responses.  Each response is a list of computes.
         # Manager should turn these into a single list of responses.
-        for i in range(3):
+        for i in xrange(3):
             cell_name = 'path!to!cell%i' % i
             compute_nodes = []
             for compute_node in FAKE_COMPUTE_NODES:
@@ -607,16 +607,17 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
     def test_validate_console_port(self):
         instance_uuid = 'fake-instance-uuid'
         cell_name = 'fake-cell-name'
-        instance = objects.Instance(cell_name=cell_name)
+        instance = {'cell_name': cell_name}
         console_port = 'fake-console-port'
         console_type = 'fake-console-type'
 
         self.mox.StubOutWithMock(self.msg_runner,
                                  'validate_console_port')
-        self.mox.StubOutWithMock(objects.Instance, 'get_by_uuid')
+        self.mox.StubOutWithMock(self.cells_manager.db,
+                                 'instance_get_by_uuid')
         fake_response = self._get_fake_response()
 
-        objects.Instance.get_by_uuid(self.ctxt,
+        self.cells_manager.db.instance_get_by_uuid(self.ctxt,
                 instance_uuid).AndReturn(instance)
         self.msg_runner.validate_console_port(self.ctxt, cell_name,
                 instance_uuid, console_port,
@@ -653,10 +654,8 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
 
     def test_get_migrations(self):
         filters = {'status': 'confirmed'}
-        cell1_migrations = objects.MigrationList(
-            objects=[objects.Migration(id=123)])
-        cell2_migrations = objects.MigrationList(
-            objects=[objects.Migration(id=456)])
+        cell1_migrations = [{'id': 123}]
+        cell2_migrations = [{'id': 456}]
         fake_responses = [self._get_fake_response(cell1_migrations),
                           self._get_fake_response(cell2_migrations)]
         self.mox.StubOutWithMock(self.msg_runner,
@@ -667,13 +666,12 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
 
         response = self.cells_manager.get_migrations(self.ctxt, filters)
 
-        self.assertEqual(cell1_migrations.objects + cell2_migrations.objects,
-                         response.objects)
+        self.assertEqual([cell1_migrations[0], cell2_migrations[0]], response)
 
     def test_get_migrations_for_a_given_cell(self):
         filters = {'status': 'confirmed', 'cell_name': 'ChildCell1'}
         target_cell = '%s%s%s' % (CONF.cells.name, '!', filters['cell_name'])
-        migrations = objects.MigrationList(objects=[objects.Migration(id=123)])
+        migrations = [{'id': 123}]
         fake_responses = [self._get_fake_response(migrations)]
         self.mox.StubOutWithMock(self.msg_runner,
                                  'get_migrations')
@@ -682,7 +680,7 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
         self.mox.ReplayAll()
 
         response = self.cells_manager.get_migrations(self.ctxt, filters)
-        self.assertEqual(migrations.objects, response.objects)
+        self.assertEqual(migrations, response)
 
     def test_instance_update_from_api(self):
         self.mox.StubOutWithMock(self.msg_runner,
@@ -786,12 +784,10 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
 
     def test_terminate_instance(self):
         self.mox.StubOutWithMock(self.msg_runner, 'terminate_instance')
-        self.msg_runner.terminate_instance(self.ctxt, 'fake-instance',
-                                           delete_type='delete')
+        self.msg_runner.terminate_instance(self.ctxt, 'fake-instance')
         self.mox.ReplayAll()
         self.cells_manager.terminate_instance(self.ctxt,
-                                              instance='fake-instance',
-                                              delete_type='delete')
+                                              instance='fake-instance')
 
     def test_soft_delete_instance(self):
         self.mox.StubOutWithMock(self.msg_runner, 'soft_delete_instance')
@@ -881,27 +877,3 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
                     instance='fake-instance', new_pass='fake-password')
             set_admin_password.assert_called_once_with(self.ctxt,
                     'fake-instance', 'fake-password')
-
-    def test_get_keypair_at_top(self):
-        keypairs = [self._get_fake_response('fake_keypair'),
-                    self._get_fake_response('fake_keypair2')]
-        with mock.patch.object(self.msg_runner,
-                               'get_keypair_at_top',
-                               return_value=keypairs) as fake_get_keypair:
-            response = self.cells_manager.get_keypair_at_top(self.ctxt,
-                                                             'fake_user_id',
-                                                             'fake_name')
-            fake_get_keypair.assert_called_once_with(self.ctxt, 'fake_user_id',
-                                                     'fake_name')
-            self.assertEqual('fake_keypair', response)
-
-    def test_get_keypair_at_top_with_empty_responses(self):
-        with mock.patch.object(self.msg_runner,
-                               'get_keypair_at_top',
-                               return_value=[]) as fake_get_keypair:
-            self.assertIsNone(
-                self.cells_manager.get_keypair_at_top(self.ctxt,
-                                                      'fake_user_id',
-                                                      'fake_name'))
-            fake_get_keypair.assert_called_once_with(self.ctxt, 'fake_user_id',
-                                                     'fake_name')
